==========
octosql-py
==========


.. image:: https://img.shields.io/pypi/v/octosql_py.svg
        :target: https://pypi.python.org/pypi/octosql.py

.. image:: https://img.shields.io/travis/styczynski/octosql.py.svg
        :target: https://travis-ci.org/styczynski/octosql.py

.. image:: https://readthedocs.org/projects/octosqlpy/badge/?version=latest
        :target: https://octosqlpy.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://img.shields.io/docker/build/styczynski/octosql-py
        :target: https://hub.docker.com/r/styczynski/octosql-py
        :alt: Docker status

.. image:: https://pyup.io/repos/github/styczynski/octosql.py/shield.svg
     :target: https://pyup.io/repos/github/styczynski/octosql.py/
     :alt: Updates

.. _readthedocs: https://octosqlpy.readthedocs.io

.. _dockerhub: https://hub.docker.com/r/styczynski/octosql-py

.. _styczynski: https://github.com/styczynski

.. _cube2222: https://github.com/cube2222

Octosql bindings for Python


* Free software: MIT license
* Documentation: readthedocs_.
* Docker image availablea at the dockerhub_


Features
--------

This package provides bindings for Octosql created with help of C/C++ and Go code.

To compile or install it you need the golang installed.


**Warning: ⚠️**
This package is still highly experimental software and is not recommended for usage other than "hacking around".
The stable version will be provided soon. Please stay tuned.

Credits
-------

* styczynski_ - Porting Octosql to Python
* cube2222_ - Creator of the Octosql